@@ -1,6 +1,6 @@
 # perldoc SIG.pm for documentation.
 # Specs: RFC 2535 section 4
-# $Id: SIG.pm,v 1.3 2002/06/17 11:37:36 olaf Exp $
+# $Id: SIG.pm,v 1.4 2002/06/17 14:36:57 olaf Exp $
 
 package Net::DNS::RR::SIG;
 
@@ -8,14 +8,14 @@ package Net::DNS::RR::SIG;
 
 use strict;
 use vars qw(@ISA $VERSION);
-use Net::DNS::SEC;
+use Net::DNS;
 use Carp;
 use File::Basename;
 use MIME::Base64;
 use Math::Pari;      #DSA relies on this.
 
 
- $VERSION = do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
+ $VERSION = do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf "%d."."%03d"x$#r,@r };
 
 
 
